# encoding: utf-8
# module System.Resources calls itself Resources
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System.Windows.Forms,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class IResourceReader(IEnumerable,IDisposable):
 """ Provides the base functionality to read data from resource files. """
 def Close(self):
  """
  Close(self: IResourceReader)

   Closes the resource reader after releasing any resources associated with it.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: IResourceReader) -> IDictionaryEnumerator

  

   Returns an System.Collections.IDictionaryEnumerator of the resources for this reader.

   Returns: A dictionary enumerator for the resources for this reader.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass

class IResourceWriter(IDisposable):
 """ Provides functionality to write resources to an output file or stream. """
 def AddResource(self,name,value):
  """
  AddResource(self: IResourceWriter,name: str,value: Array[Byte])

   Adds an 8-bit unsigned integer array as a named resource to the list of resources to be written.

  

   name: Name of a resource.

   value: Value of a resource as an 8-bit unsigned integer array.

  AddResource(self: IResourceWriter,name: str,value: object)

   Adds a named resource of type System.Object to the list of resources to be written.

  

   name: The name of the resource.

   value: The value of the resource.

  AddResource(self: IResourceWriter,name: str,value: str)

   Adds a named resource of type System.String to the list of resources to be written.

  

   name: The name of the resource.

   value: The value of the resource.
  """
  pass
 def Close(self):
  """
  Close(self: IResourceWriter)

   Closes the underlying resource file or stream,ensuring all the data has been written to the 

    file.
  """
  pass
 def Generate(self):
  """
  Generate(self: IResourceWriter)

   Writes all the resources added by the 

    System.Resources.IResourceWriter.AddResource(System.String,System.String) method to the output 

    file or stream.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class MissingManifestResourceException(SystemException,ISerializable,_Exception):
 """
 The exception thrown if the main assembly does not contain the resources for the neutral culture,and they are required because of a missing appropriate satellite assembly.

 

 MissingManifestResourceException()

 MissingManifestResourceException(message: str)

 MissingManifestResourceException(message: str,inner: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,inner=None):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,inner: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass

class MissingSatelliteAssemblyException(SystemException,ISerializable,_Exception):
 """
 The exception that is thrown when the satellite assembly for the resources of the neutral culture is missing.

 

 MissingSatelliteAssemblyException()

 MissingSatelliteAssemblyException(message: str)

 MissingSatelliteAssemblyException(message: str,cultureName: str)

 MissingSatelliteAssemblyException(message: str,inner: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,cultureName: str)

  __new__(cls: type,message: str,inner: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CultureName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of a neutral culture.



Get: CultureName(self: MissingSatelliteAssemblyException) -> str



"""



class NeutralResourcesLanguageAttribute(Attribute,_Attribute):
 """
 Informs the System.Resources.ResourceManager of the default culture of an application. This class cannot be inherited.

 

 NeutralResourcesLanguageAttribute(cultureName: str)

 NeutralResourcesLanguageAttribute(cultureName: str,location: UltimateResourceFallbackLocation)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,cultureName,location=None):
  """
  __new__(cls: type,cultureName: str)

  __new__(cls: type,cultureName: str,location: UltimateResourceFallbackLocation)
  """
  pass
 CultureName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the culture name.



Get: CultureName(self: NeutralResourcesLanguageAttribute) -> str



"""

 Location=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the location for the System.Resources.ResourceManager class to use to retrieve neutral resources by using the resource fallback process.



Get: Location(self: NeutralResourcesLanguageAttribute) -> UltimateResourceFallbackLocation



"""



class ResourceManager(object):
 """
 Represents a resource manager that provides convenient access to culture-specific resources at run time.

 

 ResourceManager(baseName: str,assembly: Assembly)

 ResourceManager(baseName: str,assembly: Assembly,usingResourceSet: Type)

 ResourceManager(resourceSource: Type)
 """
 @staticmethod
 def CreateFileBasedResourceManager(baseName,resourceDir,usingResourceSet):
  """
  CreateFileBasedResourceManager(baseName: str,resourceDir: str,usingResourceSet: Type) -> ResourceManager

  

   Returns a System.Resources.ResourceManager that searches a specific directory for resources 

    instead of in the assembly manifest.

  

  

   baseName: The root name of the resources. For example,the root name for the resource file named 

    "MyResource.en-US.resources" is "MyResource".

  

   resourceDir: The name of the directory to search for the resources.

   usingResourceSet: The System.Type of the custom System.Resources.ResourceSet to use. If null,the default runtime 

    System.Resources.ResourceSet is used.

  

   Returns: The newly created System.Resources.ResourceManager that searches a specific directory for 

    resources instead of in the assembly manifest.
  """
  pass
 def GetNeutralResourcesLanguage(self,*args):
  """
  GetNeutralResourcesLanguage(a: Assembly) -> CultureInfo

  

   Returns the System.Globalization.CultureInfo for the main assembly's neutral resources by 

    reading the value of the System.Resources.NeutralResourcesLanguageAttribute on a specified 

    System.Reflection.Assembly.

  

  

   a: The assembly for which to return a System.Globalization.CultureInfo.

   Returns: The culture from the System.Resources.NeutralResourcesLanguageAttribute,if found; otherwise,

    System.Globalization.CultureInfo.InvariantCulture.
  """
  pass
 def GetObject(self,name,culture=None):
  """
  GetObject(self: ResourceManager,name: str,culture: CultureInfo) -> object

  

   Gets the value of the specified non-string  resource localized for the specified culture.

  

   name: The name of the resource to get.

   culture: The culture for which the resource is localized. If the resource is not localized for this 

    culture,the resource manager uses fallback rules to locate an appropriate resource.If this 

    value is null,the System.Globalization.CultureInfo object is obtained using the culture's 

    System.Globalization.CultureInfo.CurrentUICulture property.

  

   Returns: The value of the resource,localized for the specified culture. If an appropriate resource set 

    exists but name cannot be found,the method returns null.

  

  GetObject(self: ResourceManager,name: str) -> object

  

   Returns the value of the specified non-string resource.

  

   name: The name of the resource to get.

   Returns: The value of the resource localized for the caller's current culture settings. If an appropriate 

    resource set exists but name cannot be found,the method returns null.
  """
  pass
 def GetResourceFileName(self,*args):
  """
  GetResourceFileName(self: ResourceManager,culture: CultureInfo) -> str

  

   Generates the name for the resource file for the given System.Globalization.CultureInfo.

  

   culture: The System.Globalization.CultureInfo for which a resource file name is constructed.

   Returns: The name that can be used for a resource file for the given System.Globalization.CultureInfo.
  """
  pass
 def GetResourceSet(self,culture,createIfNotExists,tryParents):
  """
  GetResourceSet(self: ResourceManager,culture: CultureInfo,createIfNotExists: bool,tryParents: bool) -> ResourceSet

  

   Gets the System.Resources.ResourceSet for a particular culture.

  

   culture: The System.Globalization.CultureInfo to look for.

   createIfNotExists: If true and if the System.Resources.ResourceSet has not been loaded yet,load it.

   tryParents: If the System.Resources.ResourceSet cannot be loaded,try parent 

    System.Globalization.CultureInfo objects to see if they exist.

  

   Returns: The specified System.Resources.ResourceSet.
  """
  pass
 def GetSatelliteContractVersion(self,*args):
  """
  GetSatelliteContractVersion(a: Assembly) -> Version

  

   Returns the System.Version specified by the System.Resources.SatelliteContractVersionAttribute 

    in the given assembly.

  

  

   a: The System.Reflection.Assembly for which to look up the 

    System.Resources.SatelliteContractVersionAttribute.

  

   Returns: The satellite contract System.Version of the given assembly,or null if no version was found.
  """
  pass
 def GetStream(self,name,culture=None):
  """
  GetStream(self: ResourceManager,name: str,culture: CultureInfo) -> UnmanagedMemoryStream

  

   Returns an unmanaged memory stream  object from the specified resource,using the specified 

    culture.

  

  

   name: The name of a resource.

   culture: An object that specifies the culture to use for the resource lookup. If culture is null,the 

    culture for the current thread is used.

  

   Returns: An System.IO.UnmanagedMemoryStream object.

  GetStream(self: ResourceManager,name: str) -> UnmanagedMemoryStream

  

   Returns an unmanaged memory stream object from the specified resource.

  

   name: The name of a resource.

   Returns: An unmanaged memory stream object object that represents a resource.
  """
  pass
 def GetString(self,name,culture=None):
  """
  GetString(self: ResourceManager,name: str,culture: CultureInfo) -> str

  

   Returns the value of the string resource localized for the specified culture.

  

   name: The name of the resource to get.

   culture: An object that represents the culture for which the resource is localized.

   Returns: The value of the resource localized for the specified culture,or null if name cannot be found 

    in a resource set.

  

  GetString(self: ResourceManager,name: str) -> str

  

   Returns the value of the specified string resource.

  

   name: The name of the resource to retrieve.

   Returns: The value of the resource localized for the caller's current UI culture,or null if name cannot 

    be found in a resource set.
  """
  pass
 def InternalGetResourceSet(self,*args):
  """
  InternalGetResourceSet(self: ResourceManager,culture: CultureInfo,createIfNotExists: bool,tryParents: bool) -> ResourceSet

  

   Provides the implementation for finding a System.Resources.ResourceSet.

  

   culture: The System.Globalization.CultureInfo to look for.

   createIfNotExists: If true and if the System.Resources.ResourceSet has not been loaded yet,load it.

   tryParents: If the System.Resources.ResourceSet cannot be loaded,try parent 

    System.Globalization.CultureInfo objects to see if they exist.

  

   Returns: The specified System.Resources.ResourceSet.
  """
  pass
 def ReleaseAllResources(self):
  """
  ReleaseAllResources(self: ResourceManager)

   Tells the System.Resources.ResourceManager to call System.Resources.ResourceSet.Close on all 

    System.Resources.ResourceSet objects and release all resources.
  """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,baseName: str,assembly: Assembly)

  __new__(cls: type,baseName: str,assembly: Assembly,usingResourceSet: Type)

  __new__(cls: type,resourceSource: Type)
  """
  pass
 BaseName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the root name of the resource files that the System.Resources.ResourceManager searches for resources.



Get: BaseName(self: ResourceManager) -> str



"""

 FallbackLocation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the location from which to retrieve neutral fallback resources.



"""

 IgnoreCase=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value indicating whether the current instance of ResourceManager allows case-insensitive resource lookups in the System.Resources.ResourceManager.GetString(System.String) and System.Resources.ResourceManager.GetObject(System.String) methods.



Get: IgnoreCase(self: ResourceManager) -> bool



Set: IgnoreCase(self: ResourceManager)=value

"""

 ResourceSetType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Type of the System.Resources.ResourceSet the System.Resources.ResourceManager uses to construct a System.Resources.ResourceSet object.



Get: ResourceSetType(self: ResourceManager) -> Type



"""


 BaseNameField=None
 HeaderVersionNumber=1
 MagicNumber=-1091581234
 MainAssembly=None
 ResourceSets=None


class ResourceReader(object,IResourceReader,IEnumerable,IDisposable):
 """
 Enumerates the resources in a binary resources (.resources) file by reading sequential resource name/value pairs.

 

 ResourceReader(fileName: str)

 ResourceReader(stream: Stream)
 """
 def Close(self):
  """
  Close(self: ResourceReader)

   Releases all operating system resources associated with this System.Resources.ResourceReader 

    object.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: ResourceReader)

   Releases all resources used by the current instance of the System.Resources.ResourceReader class.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: ResourceReader) -> IDictionaryEnumerator

  

   Returns an enumerator for this System.Resources.ResourceReader object.

   Returns: An enumerator for this System.Resources.ResourceReader object.
  """
  pass
 def GetResourceData(self,resourceName,resourceType,resourceData):
  """
  GetResourceData(self: ResourceReader,resourceName: str) -> (str,Array[Byte])

  

   Retrieves the type name and data of a named resource from an open resource file or stream.

  

   resourceName: The name of a resource.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,stream: Stream)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass

class ResourceSet(object,IDisposable,IEnumerable):
 """
 Stores all the resources localized for one particular culture,ignoring all other cultures,including any fallback rules.

 

 ResourceSet(fileName: str)

 ResourceSet(stream: Stream)

 ResourceSet(reader: IResourceReader)
 """
 def Close(self):
  """
  Close(self: ResourceSet)

   Closes and releases any resources used by this System.Resources.ResourceSet.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: ResourceSet)

   Disposes of the resources (other than memory) used by the current instance of 

    System.Resources.ResourceSet.
  """
  pass
 def GetDefaultReader(self):
  """
  GetDefaultReader(self: ResourceSet) -> Type

  

   Returns the preferred resource reader class for this kind of System.Resources.ResourceSet.

   Returns: Returns the System.Type for the preferred resource reader for this kind of 

    System.Resources.ResourceSet.
  """
  pass
 def GetDefaultWriter(self):
  """
  GetDefaultWriter(self: ResourceSet) -> Type

  

   Returns the preferred resource writer class for this kind of System.Resources.ResourceSet.

   Returns: Returns the System.Type for the preferred resource writer for this kind of 

    System.Resources.ResourceSet.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: ResourceSet) -> IDictionaryEnumerator

  

   Returns an System.Collections.IDictionaryEnumerator that can iterate through the 

    System.Resources.ResourceSet.

  

   Returns: An System.Collections.IDictionaryEnumerator for this System.Resources.ResourceSet.
  """
  pass
 def GetObject(self,name,ignoreCase=None):
  """
  GetObject(self: ResourceSet,name: str,ignoreCase: bool) -> object

  

   Searches for a resource object with the specified name in a case-insensitive manner,if 

    requested.

  

  

   name: Name of the resource to search for.

   ignoreCase: Indicates whether the case of the specified name should be ignored.

   Returns: The requested resource.

  GetObject(self: ResourceSet,name: str) -> object

  

   Searches for a resource object with the specified name.

  

   name: Case-sensitive name of the resource to search for.

   Returns: The requested resource.
  """
  pass
 def GetString(self,name,ignoreCase=None):
  """
  GetString(self: ResourceSet,name: str,ignoreCase: bool) -> str

  

   Searches for a System.String resource with the specified name in a case-insensitive manner,if 

    requested.

  

  

   name: Name of the resource to search for.

   ignoreCase: Indicates whether the case of the case of the specified name should be ignored.

   Returns: The value of a resource,if the value is a System.String.

  GetString(self: ResourceSet,name: str) -> str

  

   Searches for a System.String resource with the specified name.

  

   name: Name of the resource to search for.

   Returns: The value of a resource,if the value is a System.String.
  """
  pass
 def ReadResources(self,*args):
  """
  ReadResources(self: ResourceSet)

   Reads all the resources and stores them in a System.Collections.Hashtable indicated in the 

    System.Resources.ResourceSet.Table property.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,fileName: str)

  __new__(cls: type,stream: Stream)

  __new__(cls: type,reader: IResourceReader)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Reader=None
 Table=None


class ResourceWriter(object,IResourceWriter,IDisposable):
 """
 Writes resources in the system-default format to an output file or an output stream. This class cannot be inherited.

 

 ResourceWriter(fileName: str)

 ResourceWriter(stream: Stream)
 """
 def AddResource(self,name,value,closeAfterWrite=None):
  """
  AddResource(self: ResourceWriter,name: str,value: Stream,closeAfterWrite: bool)

   Adds a named resource specified as a stream to the list of resources to be written,and 

    specifies whether the stream should be closed after the System.Resources.ResourceWriter.Generate 

    method is called.

  

  

   name: The name of the resource to add.

   value: The value of the resource to add that supports the System.IO.Stream.Length property.

   closeAfterWrite: true to close the stream after the System.Resources.ResourceWriter.Generate method is called; 

    otherwise,false.

  

  AddResource(self: ResourceWriter,name: str,value: Array[Byte])

   Adds a named resource specified as a byte array to the list of resources to be written.

  

   name: The name of the resource.

   value: Value of the resource as an 8-bit unsigned integer array.

  AddResource(self: ResourceWriter,name: str,value: Stream)

   Adds a named resource specified as a stream to the list of resources to be written.

  

   name: The name of the resource to add.

   value: The value of the resource to add. The resource must support the System.IO.Stream.Length property.

  AddResource(self: ResourceWriter,name: str,value: str)

   Adds a string resource to the list of resources to be written.

  

   name: The name of the resource.

   value: The value of the resource.

  AddResource(self: ResourceWriter,name: str,value: object)

   Adds a named resource specified as an object to the list of resources to be written.

  

   name: The name of the resource.

   value: The value of the resource.
  """
  pass
 def AddResourceData(self,name,typeName,serializedData):
  """
  AddResourceData(self: ResourceWriter,name: str,typeName: str,serializedData: Array[Byte])

   Adds a unit of data as a resource to the list of resources to be written.

  

   name: A name that identifies the resource that contains the added data.

   typeName: The type name of the added data. For more information,see the Remarks section.

   serializedData: A byte array that contains the binary representation of the added data.
  """
  pass
 def Close(self):
  """
  Close(self: ResourceWriter)

   Saves the resources to the output stream and then closes it.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: ResourceWriter)

   Allows users to close the resource file or stream,explicitly releasing resources.
  """
  pass
 def Generate(self):
  """
  Generate(self: ResourceWriter)

   Saves all resources to the output stream in the system default format.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,stream: Stream)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 TypeNameConverter=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a delegate that enables resource assemblies to be written that target versions of the .NET Framework prior to the .NET Framework version�4�by using qualified assembly names.



Get: TypeNameConverter(self: ResourceWriter) -> Func[Type,str]



Set: TypeNameConverter(self: ResourceWriter)=value

"""



class ResXDataNode(object,ISerializable):
 """
 Represents an element in a resource file.

 

 ResXDataNode(name: str,value: object)

 ResXDataNode(name: str,value: object,typeNameConverter: Func[Type,str])

 ResXDataNode(name: str,fileRef: ResXFileRef)

 ResXDataNode(name: str,fileRef: ResXFileRef,typeNameConverter: Func[Type,str])
 """
 def GetNodePosition(self):
  """
  GetNodePosition(self: ResXDataNode) -> Point

  

   Gets the position of the resource in the resource file.

   Returns: A System.Drawing.Point structure specifying the location of this resource in the resource file 

    as a line position (System.Drawing.Point.X) and a column position (System.Drawing.Point.Y). If 

    this resource is not part of a resource file,returns a System.Drawing.Point structure with an 

    System.Drawing.Point.X of 0 and a System.Drawing.Point.Y of 0.
  """
  pass
 def GetValue(self,*__args):
  """
  GetValue(self: ResXDataNode,names: Array[AssemblyName]) -> object

  

   Gets the object stored by this node.

  

   names: The list of assemblies in which to look for the type of the object.

   Returns: The System.Object corresponding to the stored value.

  GetValue(self: ResXDataNode,typeResolver: ITypeResolutionService) -> object

  

   Gets the object stored by this node.

  

   typeResolver: The type resolution service to use when looking for a type converter.

   Returns: The System.Object corresponding to the stored value.
  """
  pass
 def GetValueTypeName(self,*__args):
  """
  GetValueTypeName(self: ResXDataNode,names: Array[AssemblyName]) -> str

  

   Gets the name of the type of the value.

  

   names: The assemblies to examine for the type.

   Returns: A System.String representing the fully qualified name of the type.

  GetValueTypeName(self: ResXDataNode,typeResolver: ITypeResolutionService) -> str

  

   A System.String representing the fully qualified name of the type.

  

   typeResolver: The type resolution service to use to locate a converter for this type.

   Returns: A System.String representing the fully qualified name of the type.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,name,*__args):
  """
  __new__(cls: type,name: str,value: object)

  __new__(cls: type,name: str,value: object,typeNameConverter: Func[Type,str])

  __new__(cls: type,name: str,fileRef: ResXFileRef)

  __new__(cls: type,name: str,fileRef: ResXFileRef,typeNameConverter: Func[Type,str])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Comment=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an arbitrary comment regarding this resource.



Get: Comment(self: ResXDataNode) -> str



Set: Comment(self: ResXDataNode)=value

"""

 FileRef=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the file reference for this resource.



Get: FileRef(self: ResXDataNode) -> ResXFileRef



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of this resource.



Get: Name(self: ResXDataNode) -> str



Set: Name(self: ResXDataNode)=value

"""



class ResXFileRef(object):
 """
 Represents a link to an external resource.

 

 ResXFileRef(fileName: str,typeName: str)

 ResXFileRef(fileName: str,typeName: str,textFileEncoding: Encoding)
 """
 def ToString(self):
  """
  ToString(self: ResXFileRef) -> str

  

   Gets the text representation of the current System.Resources.ResXFileRef object.

   Returns: A string that consists of the concatenated text representations of the parameters specified in 

    the current erload:System.Resources.ResXFileRef.#ctor constructor.
  """
  pass
 @staticmethod
 def __new__(self,fileName,typeName,textFileEncoding=None):
  """
  __new__(cls: type,fileName: str,typeName: str)

  __new__(cls: type,fileName: str,typeName: str,textFileEncoding: Encoding)
  """
  pass
 FileName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the file name specified in the current erload:System.Resources.ResXFileRef.#ctor constructor.



Get: FileName(self: ResXFileRef) -> str



"""

 TextFileEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the encoding specified in the current erload:System.Resources.ResXFileRef.#ctor constructor.



Get: TextFileEncoding(self: ResXFileRef) -> Encoding



"""

 TypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type name specified in the current erload:System.Resources.ResXFileRef.#ctor constructor.



Get: TypeName(self: ResXFileRef) -> str



"""


 Converter=None


class ResXResourceReader(object,IResourceReader,IEnumerable,IDisposable):
 """
 Enumerates XML resource (.resx) files and streams,and reads the sequential resource name and value pairs.

 

 ResXResourceReader(fileName: str)

 ResXResourceReader(fileName: str,typeResolver: ITypeResolutionService)

 ResXResourceReader(reader: TextReader)

 ResXResourceReader(reader: TextReader,typeResolver: ITypeResolutionService)

 ResXResourceReader(stream: Stream)

 ResXResourceReader(stream: Stream,typeResolver: ITypeResolutionService)

 ResXResourceReader(stream: Stream,assemblyNames: Array[AssemblyName])

 ResXResourceReader(reader: TextReader,assemblyNames: Array[AssemblyName])

 ResXResourceReader(fileName: str,assemblyNames: Array[AssemblyName])
 """
 def Close(self):
  """
  Close(self: ResXResourceReader)

   Releases all resources used by the System.Resources.ResXResourceReader.
  """
  pass
 def Dispose(self,*args):
  """
  Dispose(self: ResXResourceReader,disposing: bool)

   Releases the unmanaged resources used by the System.Resources.ResXResourceReader and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 @staticmethod
 def FromFileContents(fileContents,*__args):
  """
  FromFileContents(fileContents: str,assemblyNames: Array[AssemblyName]) -> ResXResourceReader

  

   Creates a new System.Resources.ResXResourceReader object and initializes it to read a string 

    whose contents are in the form of an XML resource file,and to use an array of 

    System.Reflection.AssemblyName objects to resolve type names specified in a resource.

  

  

   fileContents: A string whose contents are in the form of an XML resource file.

   assemblyNames: An array of System.Reflection.AssemblyName objects that specifies one or more assemblies. The 

    assemblies are used to resolve a type name in the resource to an actual type.

  

   Returns: An object that reads resources from the fileContents string.

  FromFileContents(fileContents: str,typeResolver: ITypeResolutionService) -> ResXResourceReader

  

   Creates a new System.Resources.ResXResourceReader object and initializes it to read a string 

    whose contents are in the form of an XML resource file,and to use an 

    System.ComponentModel.Design.ITypeResolutionService object to resolve type names specified in a 

    resource.

  

  

   fileContents: A string containing XML resource-formatted information.

   typeResolver: An object that resolves type names specified in a resource.

   Returns: An object that reads resources from the fileContents string.

  FromFileContents(fileContents: str) -> ResXResourceReader

  

   Creates a new System.Resources.ResXResourceReader object and initializes it to read a string 

    whose contents are in the form of an XML resource file.

  

  

   fileContents: A string containing XML resource-formatted information.

   Returns: An object that reads resources from the fileContents string.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: ResXResourceReader) -> IDictionaryEnumerator

  

   Returns an enumerator for the current System.Resources.ResXResourceReader object.

   Returns: An enumerator for the current System.Resources.ResourceReader object.
  """
  pass
 def GetMetadataEnumerator(self):
  """
  GetMetadataEnumerator(self: ResXResourceReader) -> IDictionaryEnumerator

  

   Provides a dictionary enumerator that can retrieve the design-time properties from the current 

    XML resource file or stream.

  

   Returns: An enumerator for the metadata in a resource.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,fileName: str,typeResolver: ITypeResolutionService)

  __new__(cls: type,reader: TextReader)

  __new__(cls: type,reader: TextReader,typeResolver: ITypeResolutionService)

  __new__(cls: type,stream: Stream)

  __new__(cls: type,stream: Stream,typeResolver: ITypeResolutionService)

  __new__(cls: type,stream: Stream,assemblyNames: Array[AssemblyName])

  __new__(cls: type,reader: TextReader,assemblyNames: Array[AssemblyName])

  __new__(cls: type,fileName: str,assemblyNames: Array[AssemblyName])
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 BasePath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the base path for the relative file path specified in a System.Resources.ResXFileRef object.



Get: BasePath(self: ResXResourceReader) -> str



Set: BasePath(self: ResXResourceReader)=value

"""

 UseResXDataNodes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether System.Resources.ResXDataNode objects are returned when reading the current XML resource file or stream.



Get: UseResXDataNodes(self: ResXResourceReader) -> bool



Set: UseResXDataNodes(self: ResXResourceReader)=value

"""



class ResXResourceSet(ResourceSet,IDisposable,IEnumerable):
 """
 Gathers all items that represent an XML resource (.resx) file into a single object.

 

 ResXResourceSet(fileName: str)

 ResXResourceSet(stream: Stream)
 """
 def Dispose(self):
  """
  Dispose(self: ResourceSet,disposing: bool)

   Releases resources (other than memory) associated with the current instance,closing internal 

    managed objects if requested.

  

  

   disposing: Indicates whether the objects contained in the current instance should be explicitly closed.
  """
  pass
 def GetDefaultReader(self):
  """
  GetDefaultReader(self: ResXResourceSet) -> Type

  

   Returns the preferred resource reader class for this kind of System.Resources.ResXResourceSet.

   Returns: The System.Type of the preferred resource reader for this kind of 

    System.Resources.ResXResourceSet.
  """
  pass
 def GetDefaultWriter(self):
  """
  GetDefaultWriter(self: ResXResourceSet) -> Type

  

   Returns the preferred resource writer class for this kind of System.Resources.ResXResourceSet.

   Returns: The System.Type of the preferred resource writer for this kind of 

    System.Resources.ResXResourceSet.
  """
  pass
 def ReadResources(self,*args):
  """
  ReadResources(self: ResourceSet)

   Reads all the resources and stores them in a System.Collections.Hashtable indicated in the 

    System.Resources.ResourceSet.Table property.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,stream: Stream)
  """
  pass
 Reader=None
 Table=None


class ResXResourceWriter(object,IResourceWriter,IDisposable):
 """
 Writes resources in an XML resource (.resx) file or an output stream.

 

 ResXResourceWriter(fileName: str)

 ResXResourceWriter(fileName: str,typeNameConverter: Func[Type,str])

 ResXResourceWriter(stream: Stream)

 ResXResourceWriter(stream: Stream,typeNameConverter: Func[Type,str])

 ResXResourceWriter(textWriter: TextWriter)

 ResXResourceWriter(textWriter: TextWriter,typeNameConverter: Func[Type,str])
 """
 def AddAlias(self,aliasName,assemblyName):
  """
  AddAlias(self: ResXResourceWriter,aliasName: str,assemblyName: AssemblyName)

   Adds the specified alias to a list of aliases.

  

   aliasName: The name of the alias.

   assemblyName: The name of the assembly represented by aliasName.
  """
  pass
 def AddMetadata(self,name,value):
  """
  AddMetadata(self: ResXResourceWriter,name: str,value: object)

   Adds a design-time property whose value is specified as an object to the list of resources to 

    write.

  

  

   name: The name of a property.

   value: An object that is the value of the property to add.

  AddMetadata(self: ResXResourceWriter,name: str,value: str)

   Adds a design-time property whose value is specified as a string to the list of resources to 

    write.

  

  

   name: The name of a property.

   value: A string that is the value of the property to add.

  AddMetadata(self: ResXResourceWriter,name: str,value: Array[Byte])

   Adds a design-time property whose value is specifed as a byte array to the list of resources to 

    write.

  

  

   name: The name of a property.

   value: A byte array containing the value of the property to add.
  """
  pass
 def AddResource(self,*__args):
  """
  AddResource(self: ResXResourceWriter,name: str,value: str)

   Adds a string resource to the resources.

  

   name: The name of the resource.

   value: The value of the resource.

  AddResource(self: ResXResourceWriter,node: ResXDataNode)

   Adds a named resource specified in a System.Resources.ResXDataNode object to the list of 

    resources to write.

  

  

   node: A System.Resources.ResXDataNode object that contains a resource name/value pair.

  AddResource(self: ResXResourceWriter,name: str,value: Array[Byte])

   Adds a named resource specified as a byte array to the list of resources to write.

  

   name: The name of the resource.

   value: The value of the resource to add as an 8-bit unsigned integer array.

  AddResource(self: ResXResourceWriter,name: str,value: object)

   Adds a named resource specified as an object to the list of resources to write.

  

   name: The name of the resource.

   value: The value of the resource.
  """
  pass
 def Close(self):
  """
  Close(self: ResXResourceWriter)

   Releases all resources used by the System.Resources.ResXResourceWriter.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: ResXResourceWriter)

   Releases all resources used by the System.Resources.ResXResourceWriter.
  """
  pass
 def Generate(self):
  """
  Generate(self: ResXResourceWriter)

   Writes all resources added by the 

    System.Resources.ResXResourceWriter.AddResource(System.String,System.Byte[]) method to the 

    output file or stream.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,fileName: str,typeNameConverter: Func[Type,str])

  __new__(cls: type,stream: Stream)

  __new__(cls: type,stream: Stream,typeNameConverter: Func[Type,str])

  __new__(cls: type,textWriter: TextWriter)

  __new__(cls: type,textWriter: TextWriter,typeNameConverter: Func[Type,str])
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 BasePath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the base path for the relative file path specified in a System.Resources.ResXFileRef object.



Get: BasePath(self: ResXResourceWriter) -> str



Set: BasePath(self: ResXResourceWriter)=value

"""


 BinSerializedObjectMimeType='application/x-microsoft.net.object.binary.base64'
 ByteArraySerializedObjectMimeType='application/x-microsoft.net.object.bytearray.base64'
 DefaultSerializedObjectMimeType='application/x-microsoft.net.object.binary.base64'
 ResMimeType='text/microsoft-resx'
 ResourceSchema='\r\n <!-- \r\n Microsoft ResX Schema \r\n \r\n Version 2.0\r\n \r\n The primary goals of this format is to allow a simple XML format \r\n that is mostly human readable. The generation and parsing of the \r\n various data types are done through the TypeConverter classes \r\n associated with the data types.\r\n \r\n Example:\r\n \r\n ... ado.net/XML headers & schema ...\r\n <resheader name="resmimetype">text/microsoft-resx</resheader>\r\n <resheader name="version">2.0</resheader>\r\n <resheader name="reader">System.Resources.ResXResourceReader,System.Windows.Forms,...</resheader>\r\n <resheader name="writer">System.Resources.ResXResourceWriter,System.Windows.Forms,...</resheader>\r\n <data name="Name1"><value>this is my long string</value><comment>this is a comment</comment></data>\r\n <data name="Color1" type="System.Drawing.Color,System.Drawing">Blue</data>\r\n <data name="Bitmap1" mimetype="application/x-microsoft.net.object.binary.base64">\r\n  <value>[base64 mime encoded serialized .NET Framework object]</value>\r\n </data>\r\n <data name="Icon1" type="System.Drawing.Icon,System.Drawing" mimetype="application/x-microsoft.net.object.bytearray.base64">\r\n  <value>[base64 mime encoded string representing a byte array form of the .NET Framework object]</value>\r\n  <comment>This is a comment</comment>\r\n </data>\r\n    \r\n There are any number of "resheader" rows that contain simple \r\n name/value pairs.\r\n \r\n Each data row contains a name,and value. The row also contains a \r\n type or mimetype. Type corresponds to a .NET class that support \r\n text/value conversion through the TypeConverter architecture. \r\n Classes that don\'t support this are serialized and stored with the \r\n mimetype set.\r\n \r\n The mimetype is used for serialized objects,and tells the \r\n ResXResourceReader how to depersist the object. This is currently not \r\n extensible. For a given mimetype the value must be set accordingly:\r\n \r\n Note - application/x-microsoft.net.object.binary.base64 is the format \r\n that the ResXResourceWriter will generate,however the reader can \r\n read any of the formats listed below.\r\n \r\n mimetype: application/x-microsoft.net.object.binary.base64\r\n value   : The object must be serialized with \r\n   : System.Runtime.Serialization.Formatters.Binary.BinaryFormatter\r\n   : and then encoded with base64 encoding.\r\n \r\n mimetype: application/x-microsoft.net.object.soap.base64\r\n value   : The object must be serialized with \r\n   : System.Runtime.Serialization.Formatters.Soap.SoapFormatter\r\n   : and then encoded with base64 encoding.\r\n\r\n mimetype: application/x-microsoft.net.object.bytearray.base64\r\n value   : The object must be serialized into a byte array \r\n   : using a System.ComponentModel.TypeConverter\r\n   : and then encoded with base64 encoding.\r\n -->\r\n <xsd:schema id="root" xmlns="" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">\r\n  <xsd:import namespace="http://www.w3.org/XML/1998/namespace"/>\r\n  <xsd:element name="root" msdata:IsDataSet="true">\r\n   <xsd:complexType>\r\n    <xsd:choice maxOccurs="unbounded">\r\n     <xsd:element name="metadata">\r\n      <xsd:complexType>\r\n       <xsd:sequence>\r\n       <xsd:element name="value" type="xsd:string" minOccurs="0"/>\r\n       </xsd:sequence>\r\n       <xsd:attribute name="name" use="required" type="xsd:string"/>\r\n       <xsd:attribute name="type" type="xsd:string"/>\r\n       <xsd:attribute name="mimetype" type="xsd:string"/>\r\n       <xsd:attribute ref="xml:space"/>       \r\n      </xsd:complexType>\r\n     </xsd:element>\r\n     <xsd:element name="assembly">\r\n       <xsd:complexType>\r\n      <xsd:attribute name="alias" type="xsd:string"/>\r\n      <xsd:attribute name="name" type="xsd:string"/>\r\n       </xsd:complexType>\r\n     </xsd:element>\r\n     <xsd:element name="data">\r\n      <xsd:complexType>\r\n       <xsd:sequence>\r\n        <xsd:element name="value" type="xsd:string" minOccurs="0" msdata:Ordinal="1" />\r\n        <xsd:element name="comment" type="xsd:string" minOccurs="0" msdata:Ordinal="2" />\r\n       </xsd:sequence>\r\n       <xsd:attribute name="name" type="xsd:string" use="required" msdata:Ordinal="1" />\r\n       <xsd:attribute name="type" type="xsd:string" msdata:Ordinal="3" />\r\n       <xsd:attribute name="mimetype" type="xsd:string" msdata:Ordinal="4" />\r\n       <xsd:attribute ref="xml:space"/>\r\n      </xsd:complexType>\r\n     </xsd:element>\r\n     <xsd:element name="resheader">\r\n      <xsd:complexType>\r\n       <xsd:sequence>\r\n        <xsd:element name="value" type="xsd:string" minOccurs="0" msdata:Ordinal="1" />\r\n       </xsd:sequence>\r\n       <xsd:attribute name="name" type="xsd:string" use="required" />\r\n      </xsd:complexType>\r\n     </xsd:element>\r\n    </xsd:choice>\r\n   </xsd:complexType>\r\n  </xsd:element>\r\n  </xsd:schema>\r\n  '
 SoapSerializedObjectMimeType='application/x-microsoft.net.object.soap.base64'
 Version='2.0'


class SatelliteContractVersionAttribute(Attribute,_Attribute):
 """
 Instructs the System.Resources.ResourceManager to ask for a particular version of a satellite assembly to simplify updates of the main assembly of an application.

 

 SatelliteContractVersionAttribute(version: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,version):
  """ __new__(cls: type,version: str) """
  pass
 Version=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the version of the satellite assemblies with the required resources.



Get: Version(self: SatelliteContractVersionAttribute) -> str



"""



class UltimateResourceFallbackLocation(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the assembly for the System.Resources.ResourceManager class to use to retrieve neutral resources by using the Packaging and Deploying Resources.

 

 enum UltimateResourceFallbackLocation,values: MainAssembly (0),Satellite (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 MainAssembly=None
 Satellite=None
 value__=None





class DebuggerTypeProxyAttribute(Attribute,_Attribute):
 """
 Specifies the display proxy for a type.

 

 DebuggerTypeProxyAttribute(type: Type)

 DebuggerTypeProxyAttribute(typeName: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,type: Type)

  __new__(cls: type,typeName: str)
  """
  pass
 ProxyTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type name of the proxy type.



Get: ProxyTypeName(self: DebuggerTypeProxyAttribute) -> str



"""

 Target=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the target type for the attribute.



Get: Target(self: DebuggerTypeProxyAttribute) -> Type



Set: Target(self: DebuggerTypeProxyAttribute)=value

"""

 TargetTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the target type.



Get: TargetTypeName(self: DebuggerTypeProxyAttribute) -> str



Set: TargetTypeName(self: DebuggerTypeProxyAttribute)=value

"""





class MarshalByValueComponent(object,IComponent,IDisposable,IServiceProvider):
 """
 Implements System.ComponentModel.IComponent and provides the base implementation for remotable components that are marshaled by value (a copy of the serialized object is passed).

 

 MarshalByValueComponent()
 """
 def Dispose(self):
  """
  Dispose(self: MarshalByValueComponent)

   Releases all resources used by the System.ComponentModel.MarshalByValueComponent.
  """
  pass
 def GetService(self,service):
  """
  GetService(self: MarshalByValueComponent,service: Type) -> object

  

   Gets the implementer of the System.IServiceProvider.

  

   service: A System.Type that represents the type of service you want.

   Returns: An System.Object that represents the implementer of the System.IServiceProvider.
  """
  pass
 def ToString(self):
  """
  ToString(self: MarshalByValueComponent) -> str

  

   Returns a System.String containing the name of the System.ComponentModel.Component,if any. This 

    method should not be overridden.

  

   Returns: A System.String containing the name of the System.ComponentModel.Component,if any.null if the 

    System.ComponentModel.Component is unnamed.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 Container=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the container for the component.



Get: Container(self: MarshalByValueComponent) -> IContainer



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component is currently in design mode.



Get: DesignMode(self: MarshalByValueComponent) -> bool



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this component.



"""

 Site=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the site of the component.



Get: Site(self: MarshalByValueComponent) -> ISite



Set: Site(self: MarshalByValueComponent)=value

"""


 Disposed=None




class ReferenceConverter(TypeConverter):
 """
 Provides a type converter to convert object references to and from other representations.

 

 ReferenceConverter(type: Type)
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: ReferenceConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Gets a value indicating whether this converter can convert an object in the given source type to 

    a reference object using the specified context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   sourceType: A System.Type that represents the type you wish to convert from.

   Returns: true if this object can perform the conversion; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: ReferenceConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts the given object to the reference type.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo that specifies the culture used to represent the font.

   value: The System.Object to convert.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: ReferenceConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the given value object to the reference type using the specified context and arguments.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo that specifies the culture used to represent the font.

   value: The System.Object to convert.

   destinationType: The type to convert the object to.

   Returns: The converted object.
  """
  pass
 def GetStandardValues(self,context=None):
  """
  GetStandardValues(self: ReferenceConverter,context: ITypeDescriptorContext) -> StandardValuesCollection

  

   Gets a collection of standard values for the reference data type.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   Returns: A System.ComponentModel.TypeConverter.StandardValuesCollection that holds a standard set of 

    valid values,or null if the data type does not support a standard set of values.
  """
  pass
 def GetStandardValuesExclusive(self,context=None):
  """
  GetStandardValuesExclusive(self: ReferenceConverter,context: ITypeDescriptorContext) -> bool

  

   Gets a value indicating whether the list of standard values returned from 

    System.ComponentModel.ReferenceConverter.GetStandardValues(System.ComponentModel.ITypeDescriptorC

    ontext) is an exclusive list.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   Returns: true because the System.ComponentModel.TypeConverter.StandardValuesCollection returned from 

    System.ComponentModel.ReferenceConverter.GetStandardValues(System.ComponentModel.ITypeDescriptorC

    ontext) is an exhaustive list of possible values. This method never returns false.
  """
  pass
 def GetStandardValuesSupported(self,context=None):
  """
  GetStandardValuesSupported(self: ReferenceConverter,context: ITypeDescriptorContext) -> bool

  

   Gets a value indicating whether this object supports a standard set of values that can be picked 

    from a list.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   Returns: true because 

    System.ComponentModel.ReferenceConverter.GetStandardValues(System.ComponentModel.ITypeDescriptorC

    ontext) can be called to find a common set of values the object supports. This method never 

    returns false.
  """
  pass
 def IsValueAllowed(self,*args):
  """
  IsValueAllowed(self: ReferenceConverter,context: ITypeDescriptorContext,value: object) -> bool

  

   Returns a value indicating whether a particular value can be added to the standard values 

    collection.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides an additional context.

   value: The value to check.

   Returns: true if the value is allowed and can be added to the standard values collection; false if the 

    value cannot be added to the standard values collection.
  """
  pass
 @staticmethod
 def __new__(self,type):
  """ __new__(cls: type,type: Type) """
  pass



class GCNotificationStatus(Enum,IComparable,IFormattable,IConvertible):
 """
 Provides information about the current registration for notification of the next full garbage collection.

 

 enum GCNotificationStatus,values: Canceled (2),Failed (1),NotApplicable (4),Succeeded (0),Timeout (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Canceled=None
 Failed=None
 NotApplicable=None
 Succeeded=None
 Timeout=None
 value__=None




class ContentAlignment(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies alignment of content on the drawing surface.

 

 enum ContentAlignment,values: BottomCenter (512),BottomLeft (256),BottomRight (1024),MiddleCenter (32),MiddleLeft (16),MiddleRight (64),TopCenter (2),TopLeft (1),TopRight (4)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BottomCenter=None
 BottomLeft=None
 BottomRight=None
 MiddleCenter=None
 MiddleLeft=None
 MiddleRight=None
 TopCenter=None
 TopLeft=None
 TopRight=None
 value__=None




class DrawListViewColumnHeaderEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.ListView.DrawColumnHeader event.

 

 DrawListViewColumnHeaderEventArgs(graphics: Graphics,bounds: Rectangle,columnIndex: int,header: ColumnHeader,state: ListViewItemStates,foreColor: Color,backColor: Color,font: Font)
 """
 def DrawBackground(self):
  """
  DrawBackground(self: DrawListViewColumnHeaderEventArgs)

   Draws the background of the column header.
  """
  pass
 def DrawText(self,flags=None):
  """
  DrawText(self: DrawListViewColumnHeaderEventArgs,flags: TextFormatFlags)

   Draws the column header text,formatting it with the specified 

    System.Windows.Forms.TextFormatFlags values.

  

  

   flags: A bitwise combination of System.Windows.Forms.TextFormatFlags values.

  DrawText(self: DrawListViewColumnHeaderEventArgs)

   Draws the column header text using the default formatting.
  """
  pass
 @staticmethod
 def __new__(self,graphics,bounds,columnIndex,header,state,foreColor,backColor,font):
  """ __new__(cls: type,graphics: Graphics,bounds: Rectangle,columnIndex: int,header: ColumnHeader,state: ListViewItemStates,foreColor: Color,backColor: Color,font: Font) """
  pass
 BackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the background color of the header.



Get: BackColor(self: DrawListViewColumnHeaderEventArgs) -> Color



"""

 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size and location of the column header to draw.



Get: Bounds(self: DrawListViewColumnHeaderEventArgs) -> Rectangle



"""

 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index of the System.Windows.Forms.ColumnHeader representing the header to draw.



Get: ColumnIndex(self: DrawListViewColumnHeaderEventArgs) -> int



"""

 DrawDefault=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the column header should be drawn by the operating system instead of owner-drawn.



Get: DrawDefault(self: DrawListViewColumnHeaderEventArgs) -> bool



Set: DrawDefault(self: DrawListViewColumnHeaderEventArgs)=value

"""

 Font=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the font used to draw the column header text.



Get: Font(self: DrawListViewColumnHeaderEventArgs) -> Font



"""

 ForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the foreground color of the header.



Get: ForeColor(self: DrawListViewColumnHeaderEventArgs) -> Color



"""

 Graphics=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Drawing.Graphics used to draw the column header.



Get: Graphics(self: DrawListViewColumnHeaderEventArgs) -> Graphics



"""

 Header=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.ColumnHeader representing the column header to draw.



Get: Header(self: DrawListViewColumnHeaderEventArgs) -> ColumnHeader



"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current state of the column header.



Get: State(self: DrawListViewColumnHeaderEventArgs) -> ListViewItemStates



"""





# encoding: utf-8
# module System.ComponentModel.Design.Serialization calls itself Serialization
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class ComponentSerializationService(object):
 """ Provides the base class for serializing a set of components or serializable objects into a serialization store. """
 def CreateStore(self):
  """
  CreateStore(self: ComponentSerializationService) -> SerializationStore

  

   Creates a new System.ComponentModel.Design.Serialization.SerializationStore.

   Returns: A new System.ComponentModel.Design.Serialization.SerializationStore.
  """
  pass
 def Deserialize(self,store,container=None):
  """
  Deserialize(self: ComponentSerializationService,store: SerializationStore,container: IContainer) -> ICollection

  

   Deserializes the given store and populates the given System.ComponentModel.IContainer with 

    deserialized System.ComponentModel.IComponent objects.

  

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to deserialize.

   container: The System.ComponentModel.IContainer to which System.ComponentModel.IComponent objects will be 

    added.

  

   Returns: A collection of objects created according to the stored state.

  Deserialize(self: ComponentSerializationService,store: SerializationStore) -> ICollection

  

   Deserializes the given store to produce a collection of objects.

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to deserialize.

   Returns: A collection of objects created according to the stored state.
  """
  pass
 def DeserializeTo(self,store,container,validateRecycledTypes=None,applyDefaults=None):
  """
  DeserializeTo(self: ComponentSerializationService,store: SerializationStore,container: IContainer,validateRecycledTypes: bool)

   Deserializes the given System.ComponentModel.Design.Serialization.SerializationStore to the 

    given container,optionally validating recycled types.

  

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to deserialize.

   container: The container to which System.ComponentModel.IComponent objects will be added.

   validateRecycledTypes: true to guarantee that the deserialization will only work if applied to an object of the same 

    type.

  

  DeserializeTo(self: ComponentSerializationService,store: SerializationStore,container: IContainer)

   Deserializes the given System.ComponentModel.Design.Serialization.SerializationStore to the 

    given container.

  

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to deserialize.

   container: The container to which System.ComponentModel.IComponent objects will be added.

  DeserializeTo(self: ComponentSerializationService,store: SerializationStore,container: IContainer,validateRecycledTypes: bool,applyDefaults: bool)

   Deserializes the given System.ComponentModel.Design.Serialization.SerializationStore to the 

    given container,optionally applying default property values.

  

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to deserialize.

   container: The container to which System.ComponentModel.IComponent objects will be added.

   validateRecycledTypes: true to guarantee that the deserialization will only work if applied to an object of the same 

    type.

  

   applyDefaults: true to indicate that the default property values should be applied.
  """
  pass
 def LoadStore(self,stream):
  """
  LoadStore(self: ComponentSerializationService,stream: Stream) -> SerializationStore

  

   Loads a System.ComponentModel.Design.Serialization.SerializationStore from a stream.

  

   stream: The System.IO.Stream from which the store will be loaded.

   Returns: A new System.ComponentModel.Design.Serialization.SerializationStore instance.
  """
  pass
 def Serialize(self,store,value):
  """
  Serialize(self: ComponentSerializationService,store: SerializationStore,value: object)

   Serializes the given object to the given 

    System.ComponentModel.Design.Serialization.SerializationStore.

  

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to which the state of value 

    will be written.

  

   value: The object to serialize.
  """
  pass
 def SerializeAbsolute(self,store,value):
  """
  SerializeAbsolute(self: ComponentSerializationService,store: SerializationStore,value: object)

   Serializes the given object,accounting for default property values.

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to which the state of value 

    will be serialized.

  

   value: The object to serialize.
  """
  pass
 def SerializeMember(self,store,owningObject,member):
  """
  SerializeMember(self: ComponentSerializationService,store: SerializationStore,owningObject: object,member: MemberDescriptor)

   Serializes the given member on the given object.

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to which the state of member 

    will be serialized.

  

   owningObject: The object to which member is attached.

   member: A System.ComponentModel.MemberDescriptor specifying the member to serialize.
  """
  pass
 def SerializeMemberAbsolute(self,store,owningObject,member):
  """
  SerializeMemberAbsolute(self: ComponentSerializationService,store: SerializationStore,owningObject: object,member: MemberDescriptor)

   Serializes the given member on the given object,accounting for the default property value.

  

   store: The System.ComponentModel.Design.Serialization.SerializationStore to which the state of member 

    will be serialized.

  

   owningObject: The object to which member is attached.

   member: The member to serialize.
  """
  pass

class ContextStack(object):
 """
 Provides a stack object that can be used by a serializer to make information available to nested serializers.

 

 ContextStack()
 """
 def Append(self,context):
  """
  Append(self: ContextStack,context: object)

   Appends an object to the end of the stack,rather than pushing it onto the top of the stack.

  

   context: A context object to append to the stack.
  """
  pass
 def Pop(self):
  """
  Pop(self: ContextStack) -> object

  

   Removes the current object off of the stack,returning its value.

   Returns: The object removed from the stack; null if no objects are on the stack.
  """
  pass
 def Push(self,context):
  """
  Push(self: ContextStack,context: object)

   Pushes,or places,the specified object onto the stack.

  

   context: The context object to push onto the stack.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 Current=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current object on the stack.



Get: Current(self: ContextStack) -> object



"""



class DefaultSerializationProviderAttribute(Attribute,_Attribute):
 """
 The System.ComponentModel.Design.Serialization.DefaultSerializationProviderAttribute attribute is placed on a serializer to indicate the class to use as a default provider of that type of serializer.

 

 DefaultSerializationProviderAttribute(providerType: Type)

 DefaultSerializationProviderAttribute(providerTypeName: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,providerType: Type)

  __new__(cls: type,providerTypeName: str)
  """
  pass
 ProviderTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type name of the serialization provider.



Get: ProviderTypeName(self: DefaultSerializationProviderAttribute) -> str



"""



class DesignerLoader(object):
 """ Provides a basic designer loader interface that can be used to implement a custom designer loader. """
 def BeginLoad(self,host):
  """
  BeginLoad(self: DesignerLoader,host: IDesignerLoaderHost)

   Begins loading a designer.

  

   host: The loader host through which this loader loads components.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: DesignerLoader)

   Releases all resources used by the System.ComponentModel.Design.Serialization.DesignerLoader.
  """
  pass
 def Flush(self):
  """
  Flush(self: DesignerLoader)

   Writes cached changes to the location that the designer was loaded from.
  """
  pass
 Loading=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the loader is currently loading a document.



Get: Loading(self: DesignerLoader) -> bool



"""



class DesignerSerializerAttribute(Attribute,_Attribute):
 """
 Indicates a serializer for the serialization manager to use to serialize the values of the type this attribute is applied to. This class cannot be inherited.

 

 DesignerSerializerAttribute(serializerType: Type,baseSerializerType: Type)

 DesignerSerializerAttribute(serializerTypeName: str,baseSerializerType: Type)

 DesignerSerializerAttribute(serializerTypeName: str,baseSerializerTypeName: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,serializerType: Type,baseSerializerType: Type)

  __new__(cls: type,serializerTypeName: str,baseSerializerType: Type)

  __new__(cls: type,serializerTypeName: str,baseSerializerTypeName: str)
  """
  pass
 SerializerBaseTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the fully qualified type name of the serializer base type.



Get: SerializerBaseTypeName(self: DesignerSerializerAttribute) -> str



"""

 SerializerTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the fully qualified type name of the serializer.



Get: SerializerTypeName(self: DesignerSerializerAttribute) -> str



"""

 TypeId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Indicates a unique ID for this attribute type.



Get: TypeId(self: DesignerSerializerAttribute) -> object



"""



class IDesignerLoaderHost(IDesignerHost,IServiceContainer,IServiceProvider):
 """ Provides an interface that can extend a designer host to support loading from a serialized state. """
 def EndLoad(self,baseClassName,successful,errorCollection):
  """
  EndLoad(self: IDesignerLoaderHost,baseClassName: str,successful: bool,errorCollection: ICollection)

   Ends the designer loading operation.

  

   baseClassName: The fully qualified name of the base class of the document that this designer is designing.

   successful: true if the designer is successfully loaded; otherwise,false.

   errorCollection: A collection containing the errors encountered during load,if any. If no errors were 

    encountered,pass either an empty collection or null.
  """
  pass
 def Reload(self):
  """
  Reload(self: IDesignerLoaderHost)

   Reloads the design document.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class IDesignerLoaderHost2(IDesignerLoaderHost,IDesignerHost,IServiceContainer,IServiceProvider):
 """ Provides an interface that extends System.ComponentModel.Design.Serialization.IDesignerLoaderHost to specify whether errors are tolerated while loading a design document. """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 CanReloadWithErrors=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether it is possible to reload with errors.



Get: CanReloadWithErrors(self: IDesignerLoaderHost2) -> bool



Set: CanReloadWithErrors(self: IDesignerLoaderHost2)=value

"""

 IgnoreErrorsDuringReload=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether errors should be ignored when System.ComponentModel.Design.Serialization.IDesignerLoaderHost.Reload is called.



Get: IgnoreErrorsDuringReload(self: IDesignerLoaderHost2) -> bool



Set: IgnoreErrorsDuringReload(self: IDesignerLoaderHost2)=value

"""



class IDesignerLoaderService:
 """ Provides an interface that can extend a designer loader to support asynchronous loading of external components. """
 def AddLoadDependency(self):
  """
  AddLoadDependency(self: IDesignerLoaderService)

   Registers an external component as part of the load process managed by this interface.
  """
  pass
 def DependentLoadComplete(self,successful,errorCollection):
  """
  DependentLoadComplete(self: IDesignerLoaderService,successful: bool,errorCollection: ICollection)

   Signals that a dependent load has finished.

  

   successful: true if the load of the designer is successful; false if errors prevented the load from 

    finishing.

  

   errorCollection: A collection of errors that occurred during the load,if any. If no errors occurred,pass either 

    an empty collection or null.
  """
  pass
 def Reload(self):
  """
  Reload(self: IDesignerLoaderService) -> bool

  

   Reloads the design document.

   Returns: true if the reload request is accepted,or false if the loader does not allow the reload.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class IDesignerSerializationManager(IServiceProvider):
 """ Provides an interface that can manage design-time serialization. """
 def AddSerializationProvider(self,provider):
  """
  AddSerializationProvider(self: IDesignerSerializationManager,provider: IDesignerSerializationProvider)

   Adds the specified serialization provider to the serialization manager.

  

   provider: The serialization provider to add.
  """
  pass
 def CreateInstance(self,type,arguments,name,addToContainer):
  """
  CreateInstance(self: IDesignerSerializationManager,type: Type,arguments: ICollection,name: str,addToContainer: bool) -> object

  

   Creates an instance of the specified type and adds it to a collection of named instances.

  

   type: The data type to create.

   arguments: The arguments to pass to the constructor for this type.

   name: The name of the object. This name can be used to access the object later through 

    System.ComponentModel.Design.Serialization.IDesignerSerializationManager.GetInstance(System.Strin

    g). If null is passed,the object is still created but cannot be accessed by name.

  

   addToContainer: If true,this object is added to the design container. The object must implement 

    System.ComponentModel.IComponent for this to have any effect.

  

   Returns: The newly created object instance.
  """
  pass
 def GetInstance(self,name):
  """
  GetInstance(self: IDesignerSerializationManager,name: str) -> object

  

   Gets an instance of a created object of the specified name,or null if that object does not 

    exist.

  

  

   name: The name of the object to retrieve.

   Returns: An instance of the object with the given name,or null if no object by that name can be found.
  """
  pass
 def GetName(self,value):
  """
  GetName(self: IDesignerSerializationManager,value: object) -> str

  

   Gets the name of the specified object,or null if the object has no name.

  

   value: The object to retrieve the name for.

   Returns: The name of the object,or null if the object is unnamed.
  """
  pass
 def GetSerializer(self,objectType,serializerType):
  """
  GetSerializer(self: IDesignerSerializationManager,objectType: Type,serializerType: Type) -> object

  

   Gets a serializer of the requested type for the specified object type.

  

   objectType: The type of the object to get the serializer for.

   serializerType: The type of the serializer to retrieve.

   Returns: An instance of the requested serializer,or null if no appropriate serializer can be located.
  """
  pass
 def GetType(self,typeName):
  """
  GetType(self: IDesignerSerializationManager,typeName: str) -> Type

  

   Gets a type of the specified name.

  

   typeName: The fully qualified name of the type to load.

   Returns: An instance of the type,or null if the type cannot be loaded.
  """
  pass
 def RemoveSerializationProvider(self,provider):
  """
  RemoveSerializationProvider(self: IDesignerSerializationManager,provider: IDesignerSerializationProvider)

   Removes a custom serialization provider from the serialization manager.

  

   provider: The provider to remove. This object must have been added using 

    System.ComponentModel.Design.Serialization.IDesignerSerializationManager.AddSerializationProvider

    (System.ComponentModel.Design.Serialization.IDesignerSerializationProvider).
  """
  pass
 def ReportError(self,errorInformation):
  """
  ReportError(self: IDesignerSerializationManager,errorInformation: object)

   Reports an error in serialization.

  

   errorInformation: The error to report. This information object can be of any object type. If it is an exception,

    the message of the exception is extracted and reported to the user. If it is any other type,

    System.Object.ToString is called to display the information to the user.
  """
  pass
 def SetName(self,instance,name):
  """
  SetName(self: IDesignerSerializationManager,instance: object,name: str)

   Sets the name of the specified existing object.

  

   instance: The object instance to name.

   name: The name to give the instance.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Context=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a stack-based,user-defined storage area that is useful for communication between serializers.



Get: Context(self: IDesignerSerializationManager) -> ContextStack



"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Indicates custom properties that can be serializable with available serializers.



Get: Properties(self: IDesignerSerializationManager) -> PropertyDescriptorCollection



"""


 ResolveName=None
 SerializationComplete=None


class IDesignerSerializationProvider:
 """ Provides an interface that enables access to a serializer. """
 def GetSerializer(self,manager,currentSerializer,objectType,serializerType):
  """
  GetSerializer(self: IDesignerSerializationProvider,manager: IDesignerSerializationManager,currentSerializer: object,objectType: Type,serializerType: Type) -> object

  

   Gets a serializer using the specified attributes.

  

   manager: The serialization manager requesting the serializer.

   currentSerializer: An instance of the current serializer of the specified type. This can be null if no serializer 

    of the specified type exists.

  

   objectType: The data type of the object to serialize.

   serializerType: The data type of the serializer to create.

   Returns: An instance of a serializer of the type requested,or null if the request cannot be satisfied.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class IDesignerSerializationService:
 """ Provides an interface that can invoke serialization and deserialization. """
 def Deserialize(self,serializationData):
  """
  Deserialize(self: IDesignerSerializationService,serializationData: object) -> ICollection

  

   Deserializes the specified serialization data object and returns a collection of objects 

    represented by that data.

  

  

   serializationData: An object consisting of serialized data.

   Returns: An System.Collections.ICollection of objects rebuilt from the specified serialization data 

    object.
  """
  pass
 def Serialize(self,objects):
  """
  Serialize(self: IDesignerSerializationService,objects: ICollection) -> object

  

   Serializes the specified collection of objects and stores them in a serialization data object.

  

   objects: A collection of objects to serialize.

   Returns: An object that contains the serialized state of the specified collection of objects.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class INameCreationService:
 """ Provides a service that can generate unique names for objects. """
 def CreateName(self,container,dataType):
  """
  CreateName(self: INameCreationService,container: IContainer,dataType: Type) -> str

  

   Creates a new name that is unique to all components in the specified container.

  

   container: The container where the new object is added.

   dataType: The data type of the object that receives the name.

   Returns: A unique name for the data type.
  """
  pass
 def IsValidName(self,name):
  """
  IsValidName(self: INameCreationService,name: str) -> bool

  

   Gets a value indicating whether the specified name is valid.

  

   name: The name to validate.

   Returns: true if the name is valid; otherwise,false.
  """
  pass
 def ValidateName(self,name):
  """
  ValidateName(self: INameCreationService,name: str)

   Gets a value indicating whether the specified name is valid.

  

   name: The name to validate.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class InstanceDescriptor(object):
 """
 Provides the information necessary to create an instance of an object. This class cannot be inherited.

 

 InstanceDescriptor(member: MemberInfo,arguments: ICollection,isComplete: bool)

 InstanceDescriptor(member: MemberInfo,arguments: ICollection)
 """
 def Invoke(self):
  """
  Invoke(self: InstanceDescriptor) -> object

  

   Invokes this instance descriptor and returns the object the descriptor describes.

   Returns: The object this instance descriptor describes.
  """
  pass
 @staticmethod
 def __new__(self,member,arguments,isComplete=None):
  """
  __new__(cls: type,member: MemberInfo,arguments: ICollection)

  __new__(cls: type,member: MemberInfo,arguments: ICollection,isComplete: bool)
  """
  pass
 Arguments=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of arguments that can be used to reconstruct an instance of the object that this instance descriptor represents.



Get: Arguments(self: InstanceDescriptor) -> ICollection



"""

 IsComplete=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the contents of this System.ComponentModel.Design.Serialization.InstanceDescriptor completely identify the instance.



Get: IsComplete(self: InstanceDescriptor) -> bool



"""

 MemberInfo=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the member information that describes the instance this descriptor is associated with.



Get: MemberInfo(self: InstanceDescriptor) -> MemberInfo



"""



class MemberRelationship(object):
 """
 Represents a single relationship between an object and a member.

 

 MemberRelationship(owner: object,member: MemberDescriptor)
 """
 def Equals(self,obj):
  """
  Equals(self: MemberRelationship,obj: object) -> bool

  

   Determines whether two System.ComponentModel.Design.Serialization.MemberRelationship instances 

    are equal.

  

  

   obj: The System.ComponentModel.Design.Serialization.MemberRelationship to compare with the current 

    System.ComponentModel.Design.Serialization.MemberRelationship.

  

   Returns: true if the specified System.ComponentModel.Design.Serialization.MemberRelationship is equal to 

    the current System.ComponentModel.Design.Serialization.MemberRelationship; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: MemberRelationship) -> int

  

   Returns the hash code for this instance.

   Returns: A hash code for the current System.ComponentModel.Design.Serialization.MemberRelationship.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,owner,member):
  """
  __new__[MemberRelationship]() -> MemberRelationship

  

  __new__(cls: type,owner: object,member: MemberDescriptor)
  """
  pass
 def __ne__(self,*args):
  pass
 IsEmpty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether this relationship is equal to the System.ComponentModel.Design.Serialization.MemberRelationship.Empty relationship.



Get: IsEmpty(self: MemberRelationship) -> bool



"""

 Member=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the related member.



Get: Member(self: MemberRelationship) -> MemberDescriptor



"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the owning object.



Get: Owner(self: MemberRelationship) -> object



"""


 Empty=None


class MemberRelationshipService(object):
 """ Provides the base class for relating one member to another. """
 def GetRelationship(self,*args):
  """
  GetRelationship(self: MemberRelationshipService,source: MemberRelationship) -> MemberRelationship

  

   Gets a relationship to the given source relationship.

  

   source: The source relationship.

   Returns: A relationship to source,or System.ComponentModel.Design.Serialization.MemberRelationship.Empty 

    if no relationship exists.
  """
  pass
 def SetRelationship(self,*args):
  """
  SetRelationship(self: MemberRelationshipService,source: MemberRelationship,relationship: MemberRelationship)

   Creates a relationship between the source object and target relationship.

  

   source: The source relationship.

   relationship: The relationship to set into the source.
  """
  pass
 def SupportsRelationship(self,source,relationship):
  """
  SupportsRelationship(self: MemberRelationshipService,source: MemberRelationship,relationship: MemberRelationship) -> bool

  

   Gets a value indicating whether the given relationship is supported.

  

   source: The source relationship.

   relationship: The relationship to set into the source.

   Returns: true if a relationship between the given two objects is supported; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]= """
  pass

class ResolveNameEventArgs(EventArgs):
 """
 Provides data for the System.ComponentModel.Design.Serialization.IDesignerSerializationManager.ResolveName event.

 

 ResolveNameEventArgs(name: str)
 """
 @staticmethod
 def __new__(self,name):
  """ __new__(cls: type,name: str) """
  pass
 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the object to resolve.



Get: Name(self: ResolveNameEventArgs) -> str



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that matches the name.



Get: Value(self: ResolveNameEventArgs) -> object



Set: Value(self: ResolveNameEventArgs)=value

"""



class ResolveNameEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that handles the System.ComponentModel.Design.Serialization.IDesignerSerializationManager.ResolveName event of a serialization manager.

 

 ResolveNameEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: ResolveNameEventHandler,sender: object,e: ResolveNameEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: ResolveNameEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: ResolveNameEventHandler,sender: object,e: ResolveNameEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class RootDesignerSerializerAttribute(Attribute,_Attribute):
 """
 Indicates the base serializer to use for a root designer object. This class cannot be inherited.

 

 RootDesignerSerializerAttribute(serializerTypeName: str,baseSerializerTypeName: str,reloadable: bool)

 RootDesignerSerializerAttribute(serializerType: Type,baseSerializerType: Type,reloadable: bool)

 RootDesignerSerializerAttribute(serializerTypeName: str,baseSerializerType: Type,reloadable: bool)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,serializerType: Type,baseSerializerType: Type,reloadable: bool)

  __new__(cls: type,serializerTypeName: str,baseSerializerType: Type,reloadable: bool)

  __new__(cls: type,serializerTypeName: str,baseSerializerTypeName: str,reloadable: bool)
  """
  pass
 Reloadable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the root serializer supports reloading of the design document without first disposing the designer host.



Get: Reloadable(self: RootDesignerSerializerAttribute) -> bool



"""

 SerializerBaseTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the fully qualified type name of the base type of the serializer.



Get: SerializerBaseTypeName(self: RootDesignerSerializerAttribute) -> str



"""

 SerializerTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the fully qualified type name of the serializer.



Get: SerializerTypeName(self: RootDesignerSerializerAttribute) -> str



"""

 TypeId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a unique ID for this attribute type.



Get: TypeId(self: RootDesignerSerializerAttribute) -> object



"""



class SerializationStore(object,IDisposable):
 """ Provides the base class for storing serialization data for the System.ComponentModel.Design.Serialization.ComponentSerializationService. """
 def Close(self):
  """
  Close(self: SerializationStore)

   Closes the serialization store.
  """
  pass
 def Dispose(self,*args):
  """
  Dispose(self: SerializationStore,disposing: bool)

   Releases the unmanaged resources used by the 

    System.ComponentModel.Design.Serialization.SerializationStore and optionally releases the 

    managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def Save(self,stream):
  """
  Save(self: SerializationStore,stream: Stream)

   Saves the store to the given stream.

  

   stream: The stream to which the store will be serialized.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Errors=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of errors that occurred during serialization or deserialization.



Get: Errors(self: SerializationStore) -> ICollection



"""






class Font(MarshalByRefObject,ICloneable,ISerializable,IDisposable):
 """
 Defines a particular format for text,including font face,size,and style attributes. This class cannot be inherited.

 

 Font(prototype: Font,newStyle: FontStyle)

 Font(family: FontFamily,emSize: Single,style: FontStyle,unit: GraphicsUnit,gdiCharSet: Byte,gdiVerticalFont: bool)

 Font(family: FontFamily,emSize: Single,style: FontStyle)

 Font(familyName: str,emSize: Single)

 Font(family: FontFamily,emSize: Single,style: FontStyle,unit: GraphicsUnit)

 Font(family: FontFamily,emSize: Single,style: FontStyle,unit: GraphicsUnit,gdiCharSet: Byte)

 Font(familyName: str,emSize: Single,style: FontStyle,unit: GraphicsUnit,gdiCharSet: Byte)

 Font(familyName: str,emSize: Single,style: FontStyle,unit: GraphicsUnit,gdiCharSet: Byte,gdiVerticalFont: bool)

 Font(family: FontFamily,emSize: Single,unit: GraphicsUnit)

 Font(family: FontFamily,emSize: Single)

 Font(familyName: str,emSize: Single,style: FontStyle,unit: GraphicsUnit)

 Font(familyName: str,emSize: Single,style: FontStyle)

 Font(familyName: str,emSize: Single,unit: GraphicsUnit)
 """
 def Clone(self):
  """
  Clone(self: Font) -> object

  

   Creates an exact copy of this System.Drawing.Font.

   Returns: The System.Drawing.Font this method creates,cast as an System.Object.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: Font)

   Releases all resources used by this System.Drawing.Font.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: Font,obj: object) -> bool

  

   Indicates whether the specified object is a System.Drawing.Font and has the same 

    System.Drawing.Font.FontFamily,System.Drawing.Font.GdiVerticalFont,

    System.Drawing.Font.GdiCharSet,System.Drawing.Font.Style,System.Drawing.Font.Size,and 

    System.Drawing.Font.Unit property values as this System.Drawing.Font.

  

  

   obj: The object to test.

   Returns: true if the obj parameter is a System.Drawing.Font and has the same 

    System.Drawing.Font.FontFamily,System.Drawing.Font.GdiVerticalFont,

    System.Drawing.Font.GdiCharSet,System.Drawing.Font.Style,System.Drawing.Font.Size,and 

    System.Drawing.Font.Unit property values as this System.Drawing.Font; otherwise,false.
  """
  pass
 @staticmethod
 def FromHdc(hdc):
  """
  FromHdc(hdc: IntPtr) -> Font

  

   Creates a System.Drawing.Font from the specified Windows handle to a device context.

  

   hdc: A handle to a device context.

   Returns: The System.Drawing.Font this method creates.
  """
  pass
 @staticmethod
 def FromHfont(hfont):
  """
  FromHfont(hfont: IntPtr) -> Font

  

   Creates a System.Drawing.Font from the specified Windows handle.

  

   hfont: A Windows handle to a GDI font.

   Returns: The System.Drawing.Font this method creates.
  """
  pass
 @staticmethod
 def FromLogFont(lf,hdc=None):
  """
  FromLogFont(lf: object) -> Font

  

   Creates a System.Drawing.Font from the specified GDI logical font (LOGFONT) structure.

  

   lf: An System.Object that represents the GDI�LOGFONT structure from which to create the 

    System.Drawing.Font.

  

   Returns: The System.Drawing.Font that this method creates.

  FromLogFont(lf: object,hdc: IntPtr) -> Font

  

   Creates a System.Drawing.Font from the specified GDI logical font (LOGFONT) structure.

  

   lf: An System.Object that represents the GDI�LOGFONT structure from which to create the 

    System.Drawing.Font.

  

   hdc: A handle to a device context that contains additional information about the lf structure.

   Returns: The System.Drawing.Font that this method creates.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Font) -> int

  

   Gets the hash code for this System.Drawing.Font.

   Returns: The hash code for this System.Drawing.Font.
  """
  pass
 def GetHeight(self,*__args):
  """
  GetHeight(self: Font,dpi: Single) -> Single

  

   Returns the height,in pixels,of this System.Drawing.Font when drawn to a device with the 

    specified vertical resolution.

  

  

   dpi: The vertical resolution,in dots per inch,used to calculate the height of the font.

   Returns: The height,in pixels,of this System.Drawing.Font.

  GetHeight(self: Font) -> Single

  

   Returns the line spacing,in pixels,of this font.

   Returns: The line spacing,in pixels,of this font.

  GetHeight(self: Font,graphics: Graphics) -> Single

  

   Returns the line spacing,in the current unit of a specified System.Drawing.Graphics,of this 

    font.

  

  

   graphics: A System.Drawing.Graphics that holds the vertical resolution,in dots per inch,of the display 

    device as well as settings for page unit and page scale.

  

   Returns: The line spacing,in pixels,of this font.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ToHfont(self):
  """
  ToHfont(self: Font) -> IntPtr

  

   Returns a handle to this System.Drawing.Font.

   Returns: A Windows handle to this System.Drawing.Font.
  """
  pass
 def ToLogFont(self,logFont,graphics=None):
  """
  ToLogFont(self: Font,logFont: object,graphics: Graphics)

   Creates a GDI logical font (LOGFONT) structure from this System.Drawing.Font.

  

   logFont: An System.Object that represents the LOGFONT structure that this method creates.

   graphics: A System.Drawing.Graphics that provides additional information for the LOGFONT structure.

  ToLogFont(self: Font,logFont: object)

   Creates a GDI logical font (LOGFONT) structure from this System.Drawing.Font.

  

   logFont: An System.Object that represents the LOGFONT structure that this method creates.
  """
  pass
 def ToString(self):
  """
  ToString(self: Font) -> str

  

   Returns a human-readable string representation of this System.Drawing.Font.

   Returns: A string that represents this System.Drawing.Font.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,prototype: Font,newStyle: FontStyle)

  __new__(cls: type,family: FontFamily,emSize: Single,style: FontStyle,unit: GraphicsUnit)

  __new__(cls: type,family: FontFamily,emSize: Single,style: FontStyle,unit: GraphicsUnit,gdiCharSet: Byte)

  __new__(cls: type,family: FontFamily,emSize: Single,style: FontStyle,unit: GraphicsUnit,gdiCharSet: Byte,gdiVerticalFont: bool)

  __new__(cls: type,familyName: str,emSize: Single,style: FontStyle,unit: GraphicsUnit,gdiCharSet: Byte)

  __new__(cls: type,familyName: str,emSize: Single,style: FontStyle,unit: GraphicsUnit,gdiCharSet: Byte,gdiVerticalFont: bool)

  __new__(cls: type,family: FontFamily,emSize: Single,style: FontStyle)

  __new__(cls: type,family: FontFamily,emSize: Single,unit: GraphicsUnit)

  __new__(cls: type,family: FontFamily,emSize: Single)

  __new__(cls: type,familyName: str,emSize: Single,style: FontStyle,unit: GraphicsUnit)

  __new__(cls: type,familyName: str,emSize: Single,style: FontStyle)

  __new__(cls: type,familyName: str,emSize: Single,unit: GraphicsUnit)

  __new__(cls: type,familyName: str,emSize: Single)
  """
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bold=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether this System.Drawing.Font is bold.



Get: Bold(self: Font) -> bool



"""

 FontFamily=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Drawing.FontFamily associated with this System.Drawing.Font.



Get: FontFamily(self: Font) -> FontFamily



"""

 GdiCharSet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a byte value that specifies the GDI character set that this System.Drawing.Font uses.



Get: GdiCharSet(self: Font) -> Byte



"""

 GdiVerticalFont=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that indicates whether this System.Drawing.Font is derived from a GDI vertical font.



Get: GdiVerticalFont(self: Font) -> bool



"""

 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the line spacing of this font.



Get: Height(self: Font) -> int



"""

 IsSystemFont=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the font is a member of System.Drawing.SystemFonts.



Get: IsSystemFont(self: Font) -> bool



"""

 Italic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether this font has the italic style applied.



Get: Italic(self: Font) -> bool



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the face name of this System.Drawing.Font.



Get: Name(self: Font) -> str



"""

 OriginalFontName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the font originally specified.



Get: OriginalFontName(self: Font) -> str



"""

 Size=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the em-size of this System.Drawing.Font measured in the units specified by the System.Drawing.Font.Unit property.



Get: Size(self: Font) -> Single



"""

 SizeInPoints=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the em-size,in points,of this System.Drawing.Font.



Get: SizeInPoints(self: Font) -> Single



"""

 Strikeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether this System.Drawing.Font specifies a horizontal line through the font.



Get: Strikeout(self: Font) -> bool



"""

 Style=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets style information for this System.Drawing.Font.



Get: Style(self: Font) -> FontStyle



"""

 SystemFontName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the system font if the System.Drawing.Font.IsSystemFont property returns true.



Get: SystemFontName(self: Font) -> str



"""

 Underline=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether this System.Drawing.Font is underlined.



Get: Underline(self: Font) -> bool



"""

 Unit=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the unit of measure for this System.Drawing.Font.



Get: Unit(self: Font) -> GraphicsUnit



"""





class SaveFileDialog(FileDialog,IComponent,IDisposable):
 """
 Prompts the user to select a location for saving a file. This class cannot be inherited.

 

 SaveFileDialog()
 """
 def Dispose(self):
  """
  Dispose(self: Component,disposing: bool)

   Releases the unmanaged resources used by the System.ComponentModel.Component and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def HookProc(self,*args):
  """
  HookProc(self: FileDialog,hWnd: IntPtr,msg: int,wparam: IntPtr,lparam: IntPtr) -> IntPtr

  

   Defines the common dialog box hook procedure that is overridden to add specific functionality to 

    the file dialog box.

  

  

   hWnd: The handle to the dialog box window.

   msg: The message received by the dialog box.

   wparam: Additional information about the message.

   lparam: Additional information about the message.

   Returns: Returns zero if the default dialog box procedure processes the message; returns a nonzero value 

    if the default dialog box procedure ignores the message.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnFileOk(self,*args):
  """
  OnFileOk(self: FileDialog,e: CancelEventArgs)

   Raises the System.Windows.Forms.FileDialog.FileOk event.

  

   e: A System.ComponentModel.CancelEventArgs that contains the event data.
  """
  pass
 def OnHelpRequest(self,*args):
  """
  OnHelpRequest(self: CommonDialog,e: EventArgs)

   Raises the System.Windows.Forms.CommonDialog.HelpRequest event.

  

   e: An System.Windows.Forms.HelpEventArgs that provides the event data.
  """
  pass
 def OpenFile(self):
  """
  OpenFile(self: SaveFileDialog) -> Stream

  

   Opens the file with read/write permission selected by the user.

   Returns: The read/write file selected by the user.
  """
  pass
 def OwnerWndProc(self,*args):
  """
  OwnerWndProc(self: CommonDialog,hWnd: IntPtr,msg: int,wparam: IntPtr,lparam: IntPtr) -> IntPtr

  

   Defines the owner window procedure that is overridden to add specific functionality to a common 

    dialog box.

  

  

   hWnd: The window handle of the message to send.

   msg: The Win32 message to send.

   wparam: The wparam to send with the message.

   lparam: The lparam to send with the message.

   Returns: The result of the message processing,which is dependent on the message sent.
  """
  pass
 def Reset(self):
  """
  Reset(self: SaveFileDialog)

   Resets all dialog box options to their default values.
  """
  pass
 def RunDialog(self,*args):
  """
  RunDialog(self: FileDialog,hWndOwner: IntPtr) -> bool

  

   Specifies a common dialog box.

  

   hWndOwner: A value that represents the window handle of the owner window for the common dialog box.

   Returns: true if the file could be opened; otherwise,false.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 CreatePrompt=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the dialog box prompts the user for permission to create a file if the user specifies a file that does not exist.



Get: CreatePrompt(self: SaveFileDialog) -> bool



Set: CreatePrompt(self: SaveFileDialog)=value

"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 Instance=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Win32 instance handle for the application.



"""

 Options=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets values to initialize the System.Windows.Forms.FileDialog.



"""

 OverwritePrompt=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the Save As dialog box displays a warning if the user specifies a file name that already exists.



Get: OverwritePrompt(self: SaveFileDialog) -> bool



Set: OverwritePrompt(self: SaveFileDialog)=value

"""





class UriParser(object):
 """ Parses a new URI scheme. This is an abstract class. """
 def GetComponents(self,*args):
  """
  GetComponents(self: UriParser,uri: Uri,components: UriComponents,format: UriFormat) -> str

  

   Gets the components from a URI.

  

   uri: The URI to parse.

   components: The System.UriComponents to retrieve from uri.

   format: One of the System.UriFormat values that controls how special characters are escaped.

   Returns: A string that contains the components.
  """
  pass
 def InitializeAndValidate(self,*args):
  """
  InitializeAndValidate(self: UriParser,uri: Uri) -> UriFormatException

  

   Initialize the state of the parser and validate the URI.

  

   uri: The T:System.Uri to validate.
  """
  pass
 def IsBaseOf(self,*args):
  """
  IsBaseOf(self: UriParser,baseUri: Uri,relativeUri: Uri) -> bool

  

   Determines whether baseUri is a base URI for relativeUri.

  

   baseUri: The base URI.

   relativeUri: The URI to test.

   Returns: true if baseUri is a base URI for relativeUri; otherwise,false.
  """
  pass
 @staticmethod
 def IsKnownScheme(schemeName):
  """
  IsKnownScheme(schemeName: str) -> bool

  

   Indicates whether the parser for a scheme is registered.

  

   schemeName: The scheme name to check.

   Returns: true if schemeName has been registered; otherwise,false.
  """
  pass
 def IsWellFormedOriginalString(self,*args):
  """
  IsWellFormedOriginalString(self: UriParser,uri: Uri) -> bool

  

   Indicates whether a URI is well-formed.

  

   uri: The URI to check.

   Returns: true if uri is well-formed; otherwise,false.
  """
  pass
 def OnNewUri(self,*args):
  """
  OnNewUri(self: UriParser) -> UriParser

  

   Invoked by a System.Uri constructor to get a System.UriParser instance

   Returns: A System.UriParser for the constructed System.Uri.
  """
  pass
 def OnRegister(self,*args):
  """
  OnRegister(self: UriParser,schemeName: str,defaultPort: int)

   Invoked by the Framework when a System.UriParser method is registered.

  

   schemeName: The scheme that is associated with this System.UriParser.

   defaultPort: The port number of the scheme.
  """
  pass
 @staticmethod
 def Register(uriParser,schemeName,defaultPort):
  """
  Register(uriParser: UriParser,schemeName: str,defaultPort: int)

   Associates a scheme and port number with a System.UriParser.

  

   uriParser: The URI parser to register.

   schemeName: The name of the scheme that is associated with this parser.

   defaultPort: The default port number for the specified scheme.
  """
  pass
 def Resolve(self,*args):
  """
  Resolve(self: UriParser,baseUri: Uri,relativeUri: Uri) -> (str,UriFormatException)

  

   Called by System.Uri constructors and erload:System.Uri.TryCreate to resolve a relative URI.

  

   baseUri: A base URI.

   relativeUri: A relative URI.

   Returns: The string of the resolved relative System.Uri.
  """
  pass



# -*- coding: utf-8 -*-
"""Route custom exceptions."""
#pylint: disable=import-error,invalid-name,broad-except
from pyrevit import HOST_APP


class ServerException(Exception):
    """Server error."""
    def __init__(self, message, exception_type, exception_traceback):
        message = "Server error (%s): %s\n%s\n" % (
            exception_type.__name__ if exception_type else "",
            message,
            exception_traceback
        )
        super(ServerException, self).__init__(message)
        self.status = 500 # https://httpstatuses.com/500


class APINotDefinedException(Exception):
    """API is not defined exception."""
    def __init__(self, api_name):
        message = "API is not defined: \"%s\"" % api_name
        super(APINotDefinedException, self).__init__(message)
        self.status = 404 # https://httpstatuses.com/404


class RouteHandlerNotDefinedException(Exception):
    """Route does not exits exception."""
    def __init__(self, api_name, route, method):
        message = \
        "Route does not exits: \"%s %s%s\"" % (method, api_name, route)
        super(RouteHandlerNotDefinedException, self).__init__(message)
        self.status = 404 # https://httpstatuses.com/404


class RouteHandlerDeniedException(Exception):
    """Route handler was denied by host."""
    def __init__(self, request):
        message = "Route handler was denied by host: \"%s\"" % request.route
        super(RouteHandlerDeniedException, self).__init__(message)
        self.status = 406 # https://httpstatuses.com/406
        self.source = HOST_APP.pretty_name


class RouteHandlerTimedOutException(Exception):
    """Route handler was timed out by host."""
    def __init__(self, request):
        message = "Route handler was timed out by host: \"%s\"" % request.route
        super(RouteHandlerTimedOutException, self).__init__(message)
        self.status = 408 # https://httpstatuses.com/408
        self.source = HOST_APP.pretty_name


class RouteHandlerIsNotCallableException(Exception):
    """Route handler is not callable."""
    def __init__(self, hndlr_name):
        message = "Route handler is not callable: \"%s\"" % hndlr_name
        super(RouteHandlerIsNotCallableException, self).__init__(message)
        self.status = 405 # https://httpstatuses.com/405
        self.source = HOST_APP.pretty_name


class RouteHandlerExecException(Exception):
    """Route handler exception."""
    def __init__(self, message):
        message = "Route exception in Execute: %s" % message
        super(RouteHandlerExecException, self).__init__(message)
        self.status = 408 # https://httpstatuses.com/408
        self.source = HOST_APP.pretty_name


class RouteHandlerException(Exception):
    """Route handler exception."""
    def __init__(self,
                 message, exception_type, exception_traceback,
                 clsx_message, clsx_source, clsx_stacktrace, clsx_targetsite):
        message = "%s: %s\n%s\n" \
                  "Script Executor Traceback:\n" \
                  "%s: %s\n%s\n%s" % (
                      exception_type.__name__ if exception_type else "",
                      message,
                      exception_traceback,
                      clsx_source,
                      clsx_message,
                      clsx_stacktrace,
                      clsx_targetsite
                  )
        super(RouteHandlerException, self).__init__(message)
        self.status = 408 # https://httpstatuses.com/408
        self.source = HOST_APP.pretty_name



class IIntellisenseBuilder:
 """ Provides an interface to facilitate the retrieval of the builder's name and to display the builder. """
 def Show(self,language,value,newValue):
  """
  Show(self: IIntellisenseBuilder,language: str,value: str,newValue: str) -> (bool,str)

  

   Shows the builder.

  

   language: The language service that is calling the builder.

   value: The expression being edited.

   newValue: The new value.

   Returns: true if the value should be replaced with newValue; otherwise,false (if the user cancels,for 

    example).
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a localized name.



Get: Name(self: IIntellisenseBuilder) -> str



"""





class BindingsCollection(BaseCollection,ICollection,IEnumerable):
 """ Represents a collection of System.Windows.Forms.Binding objects for a control. """
 def Add(self,*args):
  """
  Add(self: BindingsCollection,binding: Binding)

   Adds the specified binding to the collection.

  

   binding: The System.Windows.Forms.Binding to add to the collection.
  """
  pass
 def AddCore(self,*args):
  """
  AddCore(self: BindingsCollection,dataBinding: Binding)

   Adds a System.Windows.Forms.Binding to the collection.

  

   dataBinding: The System.Windows.Forms.Binding to add to the collection.
  """
  pass
 def Clear(self,*args):
  """
  Clear(self: BindingsCollection)

   Clears the collection of binding objects.
  """
  pass
 def ClearCore(self,*args):
  """
  ClearCore(self: BindingsCollection)

   Clears the collection of any members.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: BindingsCollection,ccevent: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.BindingsCollection.CollectionChanged event.

  

   ccevent: A System.ComponentModel.CollectionChangeEventArgs that contains the event data.
  """
  pass
 def OnCollectionChanging(self,*args):
  """
  OnCollectionChanging(self: BindingsCollection,e: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.BindingsCollection.CollectionChanging event.

  

   e: A System.ComponentModel.CollectionChangeEventArgs that contains event data.
  """
  pass
 def Remove(self,*args):
  """
  Remove(self: BindingsCollection,binding: Binding)

   Deletes the specified binding from the collection.

  

   binding: The Binding to remove from the collection.
  """
  pass
 def RemoveAt(self,*args):
  """
  RemoveAt(self: BindingsCollection,index: int)

   Deletes the binding from the collection at the specified index.

  

   index: The index of the System.Windows.Forms.Binding to remove.
  """
  pass
 def RemoveCore(self,*args):
  """
  RemoveCore(self: BindingsCollection,dataBinding: Binding)

   Removes the specified System.Windows.Forms.Binding from the collection.

  

   dataBinding: The System.Windows.Forms.Binding to remove.
  """
  pass
 def ShouldSerializeMyAll(self,*args):
  """
  ShouldSerializeMyAll(self: BindingsCollection) -> bool

  

   Gets a value that indicates whether the collection should be serialized.

   Returns: true if the collection count is greater than zero; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total number of bindings in the collection.



Get: Count(self: BindingsCollection) -> int



"""

 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the bindings in the collection as an object.



"""


 CollectionChanged=None
 CollectionChanging=None




"""MathNet importer module.

See https://www.mathdotnet.com for documentation.

Examples:
    ```python
    from pyrevit.coreutils.mathnet import MathNet
    ```
"""
#pylint: disable=W0703,C0302,C0103
from pyrevit import framework
from pyrevit.framework import clr
from pyrevit.coreutils.logger import get_logger


mlogger = get_logger(__name__)


MATHNET_LIB = 'MathNet.Numerics'

mathnet_dll = framework.get_dll_file(MATHNET_LIB)
mlogger.debug('Loading dll: %s', mathnet_dll)
try:
    clr.AddReferenceToFileAndPath(mathnet_dll)
    import MathNet  #pylint: disable=E0401,W0611
except Exception as load_err:
    mlogger.error('Can not load %s module. | %s', MATHNET_LIB, load_err)



class DataGridViewCellToolTipTextNeededEventArgs(DataGridViewCellEventArgs):
 """ Provides data for the System.Windows.Forms.DataGridView.CellToolTipTextNeeded event. """
 ToolTipText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the ToolTip text.



Get: ToolTipText(self: DataGridViewCellToolTipTextNeededEventArgs) -> str



Set: ToolTipText(self: DataGridViewCellToolTipTextNeededEventArgs)=value

"""





class BindableAttribute(Attribute,_Attribute):
 """
 Specifies whether a member is typically used for binding. This class cannot be inherited.

 

 BindableAttribute(bindable: bool)

 BindableAttribute(bindable: bool,direction: BindingDirection)

 BindableAttribute(flags: BindableSupport)

 BindableAttribute(flags: BindableSupport,direction: BindingDirection)
 """
 def Equals(self,obj):
  """
  Equals(self: BindableAttribute,obj: object) -> bool

  

   Determines whether two System.ComponentModel.BindableAttribute objects are equal.

  

   obj: The object to compare.

   Returns: true if the specified System.ComponentModel.BindableAttribute is equal to the current 

    System.ComponentModel.BindableAttribute; false if it is not equal.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: BindableAttribute) -> int

  

   Serves as a hash function for the System.ComponentModel.BindableAttribute class.

   Returns: A hash code for the current System.ComponentModel.BindableAttribute.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: BindableAttribute) -> bool

  

   Determines if this attribute is the default.

   Returns: true if the attribute is the default value for this attribute class; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,bindable: bool)

  __new__(cls: type,bindable: bool,direction: BindingDirection)

  __new__(cls: type,flags: BindableSupport)

  __new__(cls: type,flags: BindableSupport,direction: BindingDirection)
  """
  pass
 def __ne__(self,*args):
  pass
 Bindable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating that a property is typically used for binding.



Get: Bindable(self: BindableAttribute) -> bool



"""

 Direction=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the direction or directions of this property's data binding.



Get: Direction(self: BindableAttribute) -> BindingDirection



"""


 Default=None
 No=None
 Yes=None




class TypeListConverter(TypeConverter):
 """ Provides a type converter that can be used to populate a list box with available types. """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: TypeListConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Gets a value indicating whether this converter can convert the specified System.Type of the 

    source object using the given context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   sourceType: The System.Type of the source object.

   Returns: true if this converter can perform the conversion; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: TypeListConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Gets a value indicating whether this converter can convert an object to the given destination 

    type using the context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   destinationType: A System.Type that represents the type you wish to convert to.

   Returns: true if this converter can perform the conversion; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: TypeListConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts the specified object to the native type of the converter.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo that specifies the culture used to represent the font.

   value: The System.Object to convert.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: TypeListConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the given value object to the specified destination type.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: An optional System.Globalization.CultureInfo. If not supplied,the current culture is assumed.

   value: The System.Object to convert.

   destinationType: The System.Type to convert the value to.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def GetStandardValues(self,context=None):
  """
  GetStandardValues(self: TypeListConverter,context: ITypeDescriptorContext) -> StandardValuesCollection

  

   Gets a collection of standard values for the data type this validator is designed for.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   Returns: A System.ComponentModel.TypeConverter.StandardValuesCollection that holds a standard set of 

    valid values,or null if the data type does not support a standard set of values.
  """
  pass
 def GetStandardValuesExclusive(self,context=None):
  """
  GetStandardValuesExclusive(self: TypeListConverter,context: ITypeDescriptorContext) -> bool

  

   Gets a value indicating whether the list of standard values returned from the 

    System.ComponentModel.TypeListConverter.GetStandardValues(System.ComponentModel.ITypeDescriptorCo

    ntext) method is an exclusive list.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   Returns: true because the System.ComponentModel.TypeConverter.StandardValuesCollection returned from 

    System.ComponentModel.TypeListConverter.GetStandardValues(System.ComponentModel.ITypeDescriptorCo

    ntext) is an exhaustive list of possible values. This method never returns false.
  """
  pass
 def GetStandardValuesSupported(self,context=None):
  """
  GetStandardValuesSupported(self: TypeListConverter,context: ITypeDescriptorContext) -> bool

  

   Gets a value indicating whether this object supports a standard set of values that can be picked 

    from a list using the specified context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   Returns: true because 

    System.ComponentModel.TypeListConverter.GetStandardValues(System.ComponentModel.ITypeDescriptorCo

    ntext) should be called to find a common set of values the object supports. This method never 

    returns false.
  """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """ __new__(cls: type,types: Array[Type]) """
  pass



class DataGridClipboardCellContent(object):
 """
 Encapsulates the value and location of a System.Windows.Controls.DataGrid cell for use when copying content to the Clipboard.

 

 DataGridClipboardCellContent(item: object,column: DataGridColumn,content: object)
 """
 def Equals(self,data):
  """
  Equals(self: DataGridClipboardCellContent,data: object) -> bool

  

   Indicates whether the current and specified System.Windows.Controls.DataGridClipboardCellContent 

    instances are equivalent.

  

  

   data: The System.Windows.Controls.DataGridClipboardCellContent instance to compare with the current 

    System.Windows.Controls.DataGridClipboardCellContent instance.

  

   Returns: true if the current and specified System.Windows.Controls.DataGridClipboardCellContent instances 

    have the same System.Windows.Controls.DataGridClipboardCellContent.Item,

    System.Windows.Controls.DataGridClipboardCellContent.Column,and 

    System.Windows.Controls.DataGridClipboardCellContent.Content property values; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DataGridClipboardCellContent) -> int

  

   Returns the hash code for this System.Windows.Controls.DataGridClipboardCellContent instance.

   Returns: The hash code for this System.Windows.Controls.DataGridClipboardCellContent instance.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 @staticmethod
 def __new__(self,item,column,content):
  """
  __new__(cls: type,item: object,column: DataGridColumn,content: object)

  __new__[DataGridClipboardCellContent]() -> DataGridClipboardCellContent
  """
  pass
 def __ne__(self,*args):
  pass
 Column=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column that contains the cell being copied.



Get: Column(self: DataGridClipboardCellContent) -> DataGridColumn



"""

 Content=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the text value of the cell being copied.



Get: Content(self: DataGridClipboardCellContent) -> object



"""

 Item=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the data item for the row that contains the cell being copied.



Get: Item(self: DataGridClipboardCellContent) -> object



"""





class ItemsPanelTemplate(FrameworkTemplate,INameScope,ISealable,IHaveResources,IQueryAmbient):
 """
 Specifies the panel that the System.Windows.Controls.ItemsPresenter creates for the layout of the items of an System.Windows.Controls.ItemsControl.

 

 ItemsPanelTemplate()

 ItemsPanelTemplate(root: FrameworkElementFactory)
 """
 def ValidateTemplatedParent(self,*args):
  """
  ValidateTemplatedParent(self: ItemsPanelTemplate,templatedParent: FrameworkElement)

   Checks that the templated parent is a non-null System.Windows.Controls.ItemsPresenter object.

  

   templatedParent: The element this template is applied to. This must be an System.Windows.Controls.ItemsPresenter 

    object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,root=None):
  """
  __new__(cls: type)

  __new__(cls: type,root: FrameworkElementFactory)
  """
  pass
